anagram
========

I'm a small script that help you get anagram use wordsmith.org.

Install
=======

..  code:: bash

    $ pip install anagram

Usage
=====

``anagram``: normal use, type word or sentence in shell, return anagrams.

Example
=======

Use a single word
=========
..  code:: bash

    $ anagram cat
    1. act
    2. cat

Use a sentence
=========
..  code:: bash

    $  anagram a dog
    1. goad
    2. a god
    3. a dog
    4. ad go

Changelog
=======

- v0.0.2

  - first version, with base function.

LICENSE
=======

MIT.
